==> mingw-w64-python-ipywidgets-7.5.1-1.src.tar.gz: ipywidgets-7.5.1/examples/web2/webpack.config.js <==
var path = require('path');

module.exports = {
    mode: 'development',
    entry: './index.js',
    output: {
        filename: 'index.built.js',
        path: path.resolve(__dirname, 'built'),
        publicPath: 'built/'
    },
    module: {
        rules: [
            { test: /\.css$/, loader: "style-loader!css-loader" },
            { test: /\.py$/, loader: "raw-loader" },
            // jquery-ui loads some images
            { test: /\.(jpg|png|gif)$/, use: 'file-loader' },
            // required to load font-awesome
            { test: /\.woff2(\?v=\d+\.\d+\.\d+)?$/, use: {
                loader: 'url-loader',
                options: {
                    limit: 10000,
                    mimetype: 'application/font-woff'
                }
            }},
            { test: /\.woff(\?v=\d+\.\d+\.\d+)?$/, use: {
                loader: 'url-loader',
                options: {
                    limit: 10000,
                    mimetype: 'application/font-woff'
                }
            }},
            { test: /\.ttf(\?v=\d+\.\d+\.\d+)?$/, use: {
                loader: 'url-loader',
                options: {
                    limit: 10000,
                    mimetype: 'application/octet-stream'
                }
            }},
            { test: /\.eot(\?v=\d+\.\d+\.\d+)?$/, use: 'file-loader' },
            { test: /\.svg(\?v=\d+\.\d+\.\d+)?$/, use: {
                loader: 'url-loader',
                options: {
                    limit: 10000,
                    mimetype: 'image/svg+xml'
                }
            }}
        ]
    },
};

==> mingw-w64-python-ipywidgets-7.6.3-1.src.tar.gz: ipywidgets-7.6.3/examples/web2/webpack.config.js <==
var path = require('path');

module.exports = {
    mode: 'development',
    entry: './index.js',
    output: {
        filename: 'index.built.js',
        path: path.resolve(__dirname, 'built'),
        publicPath: 'built/'
    },
    module: {
        rules: [
            { test: /\.css$/, use: ['style-loader', 'css-loader']},
            { test: /\.py$/, loader: "raw-loader" },
            // jquery-ui loads some images
            { test: /\.(jpg|png|gif)$/, use: 'file-loader' },
            // required to load font-awesome
            { test: /\.woff2(\?v=\d+\.\d+\.\d+)?$/, use: {
                loader: 'url-loader',
                options: {
                    limit: 10000,
                    mimetype: 'application/font-woff'
                }
            }},
            { test: /\.woff(\?v=\d+\.\d+\.\d+)?$/, use: {
                loader: 'url-loader',
                options: {
                    limit: 10000,
                    mimetype: 'application/font-woff'
                }
            }},
            { test: /\.ttf(\?v=\d+\.\d+\.\d+)?$/, use: {
                loader: 'url-loader',
                options: {
                    limit: 10000,
                    mimetype: 'application/octet-stream'
                }
            }},
            { test: /\.eot(\?v=\d+\.\d+\.\d+)?$/, use: 'file-loader' },
            { test: /\.svg(\?v=\d+\.\d+\.\d+)?$/, use: {
                loader: 'url-loader',
                options: {
                    limit: 10000,
                    mimetype: 'image/svg+xml'
                }
            }}
        ]
    },
};
